package webserver

import (
	"embed"
	"io/fs"
	"net/http"
	"strings"
)

//go:generate cp -r ../../web/dist ./
//go:embed dist
var staticFiles embed.FS

type ginFS struct {
	fs http.FileSystem
}

func newFS() *ginFS {
	f, _ := fs.Sub(staticFiles, "dist")
	return &ginFS{
		fs: http.FS(f),
	}
}

func (s *ginFS) Exists(prefix string, filepath string) bool {
	if p := strings.TrimPrefix(filepath, prefix); len(p) < len(filepath) {
		if _, err := s.fs.Open(p); err != nil {
			return false
		}
		return true
	}
	return false
}

func (s *ginFS) Open(name string) (http.File, error) {
	return s.fs.Open(name)
}
